export default {
  'a': {
    'charset': {
      name: '规定被链接文档的字符集(HTML5中不支持)',
      tips: [
        { value: 'UTF-8', label: 'Unicode字符编码' },
        { value: 'ISO-8859-1', label: '拉丁字母表的编码' },
        { value: 'GB2312', label: '简体汉字编码' },
        { value: 'BIG5', label: '繁体汉字编码' }
      ]
    },
    'href': {
      name: '规定链接指向的页面的 URL',
      tips: [{ value: 'http://', label: '超链接的路径' }]
    },
    'coords': {
      name: '规定链接的坐标(HTML5中不支持)',
      tips: [{ value: 'x1,y1,x2,y2', label: '如果 shape 属性设置为 "rect"，则该值规定矩形左上角和右下角的坐标' },
        { value: 'x,y,radius', label: '如果 shape 属性设置为 "circ"，则该值规定圆心的坐标和半径' },
        {
          value: 'x1,y1,x2,y2,..,xn,yn',
          label: '如果 shape 属性设置为 "poly"，则该值规定多边形各边的坐标。如果第一个坐标和最后一个坐标不一致，那么为了关闭多边形，浏览器必须添加最后一对坐标'
        }]
    },
    'download': {
      name: '规定被下载的超链接目标',
      tips: [{ value: 'filename', label: '规定作为文件名来使用的文本' }]
    },
    'hreflang': {
      name: '规定被链接文档的语言',
      tips: [
        { value: 'zh', label: '中文(简体)' },
        { value: 'en', label: '英文' },
        { value: 'ja', label: '日语' },
        { value: 'ko', label: '韩语' },
        { value: 'https://www.w3school.com.cn/tags/html_ref_language_codes.asp', label: '语言对照表' }
      ]
    },
    'media': {
      name: '规定被链接文档是为何种媒介/设备优化的',
      tips: [
        { value: 'print and (resolution:300dpi)', label: '该属性可接受多个值。设备，可能的运算符，值。支持and、not、,运算符' },
        { value: 'all', label: '默认。适合所有设备' },
        { value: 'aural', label: '语音合成器' },
        { value: 'braille', label: '盲文反馈装置' },
        { value: 'handheld', label: '手持设备（小屏幕、有限的带宽）' },
        { value: 'projection', label: '投影机' },
        { value: 'print', label: '打印预览模式/打印页面' },
        { value: 'screen', label: '计算机屏幕' },
        { value: 'tty', label: '电传打字机以及使用等宽字符网格的类似媒介' },
        { value: 'tv', label: '电视类型设备（低分辨率、有限的分页能力）' },
        { value: 'width', label: '规定目标显示区域的宽度，可使用 "min-" 和 "max-" 前缀' },
        { value: 'height', label: '规定目标显示区域的高度，可使用 "min-" 和 "max-" 前缀' },
        { value: 'device-width', label: '规定目标显示器/纸张的宽度，可使用 "min-" 和 "max-" 前缀' },
        { value: 'device-height', label: '规定目标显示器/纸张的高度，可使用 "min-" 和 "max-" 前缀' },
        { value: 'orientation', label: '规定目标显示器/纸张的取向，可能的值："portrait" 或 "landscape"' },
        { value: 'aspect-ratio', label: '规定目标显示区域的宽度/高度比，可使用 "min-" 和 "max-" 前缀' },
        { value: 'device-aspect-ratio', label: '规定目标显示器/纸张的 device-width/device-height 比率，可使用 "min-" 和 "max-" 前缀' },
        { value: 'color', label: '规定目标显示器的 bits per color，可使用 "min-" 和 "max-" 前缀' },
        { value: 'color-index', label: '规定目标显示器能够处理的颜色数，可使用 "min-" 和 "max-" 前缀' },
        { value: 'monochrome', label: '规定在单色帧缓冲中的每像素比特，可使用 "min-" 和 "max-" 前缀' },
        { value: 'resolution', label: '规定目标显示器/纸张的像素密度 (dpi or dpcm)，可使用 "min-" 和 "max-" 前缀' },
        { value: 'scan', label: '规定 tv 显示器的扫描方法，可能的值是："progressive" 和 "interlace"' },
        { value: 'grid', label: '规定输出设备是网格还是位图，可能的值："1" 代表网格，"0" 是其他' }
      ]
    },
    'rel': {
      name: '规定当前文档与被链接文档之间的关系',
      tips: [{ value: 'alternate', label: '文档的可选版本（例如打印页、翻译页或镜像）' },
        { value: 'stylesheet', label: '文档的外部样式表' },
        { value: 'start', label: '集合中的第一个文档' },
        { value: 'next', label: '集合中的下一个文档' },
        { value: 'prev', label: '集合中的前一个文档' },
        { value: 'contents', label: '文档目录' },
        { value: 'index', label: '文档索引' },
        { value: 'glossary', label: '文档中所用字词的术语表或解释' },
        { value: 'copyright', label: '包含版权信息的文档' },
        { value: 'chapter', label: '文档的章' },
        { value: 'section', label: '文档的节' },
        { value: 'subsection', label: '文档的子段' },
        { value: 'appendix', label: '文档附录' },
        { value: 'help', label: '帮助文档' },
        { value: 'bookmark', label: '相关文档' },
        { value: 'nofollow', label: 'Google 使用 "nofollow"，用于指定 Google 搜索引擎不要跟踪链接' },
        { value: 'licence', label: '' },
        { value: 'tag', label: '' },
        { value: 'friend', label: '' }
      ]
    },
    'rev': {
      name: '规定被链接文档与当前文档之间的关系(HTML5中不支持)',
      tips: [
        { value: 'alternate', label: '文档的可选版本（例如打印页、翻译页或镜像）' },
        { value: 'stylesheet', label: '文档的外部样式表' },
        { value: 'start', label: '集合中的第一个文档' },
        { value: 'next', label: '集合中的下一个文档' },
        { value: 'prev', label: '集合中的前一个文档' },
        { value: 'contents', label: '文档目录' },
        { value: 'index', label: '文档索引' },
        { value: 'glossary', label: '文档中所用字词的术语表或解释' },
        { value: 'copyright', label: '包含版权信息的文档' },
        { value: 'chapter', label: '文档的章' },
        { value: 'section', label: '文档的节' },
        { value: 'subsection', label: '文档的子段' },
        { value: 'appendix', label: '文档附录' },
        { value: 'help', label: '帮助文档' },
        { value: 'bookmark', label: '相关文档' },
        { value: 'nofollow', label: 'Google 使用 "nofollow"，用于指定 Google 搜索引擎不要跟踪链接' }
      ]
    },
    'shape': {
      name: '规定链接的形状(HTML5中不支持)',
      tips: [{ value: 'default', label: '规定全部区域' },
        { value: 'rect', label: '定义矩形区域' },
        { value: 'circle', label: '定义圆形' },
        { value: 'poly', label: '定义多边形区域' }
      ]
    },
    'target': {
      name: '规定链接的形状',
      tips: [{ value: '_blank', label: '在新窗口中打开被链接文档' },
        { value: '_self', label: '默认。在相同的框架中打开被链接文档' },
        { value: '_parent', label: '在父框架集中打开被链接文档' },
        { value: '_top', label: '在整个窗口中打开被链接文档' },
        { value: 'framename', label: '在指定的框架中打开被链接文档' }
      ]
    },
    'type': {
      name: '规定被链接文档的的 MIME 类型',
      tips: [
        { value: 'text/html', label: '超文本标记语言文本(.html，.htm)' },
        { value: 'text/plain', label: '普通文本(.txt)' },
        { value: 'image/gif', label: 'GIF图形(.gif)' },
        { value: 'image/jpeg', label: 'JPEG图形(.jpeg，.jpg)' },
        { value: 'text/css', label: '层叠样式文本(.css)' },
        { value: 'audio/mpeg', label: '音频文件(.mp3)' },
        { value: 'application/pdf', label: '便携式文档格式(.pdf)' },
        { value: 'application/msword', label: 'Word文档(.doc)' },
        { value: 'application/zip', label: '压缩文件(.zip)' },
        { value: 'application/octet-stream', label: '下载文件类型(.exe)' },
        { value: 'text/javascript', label: 'javascript' }
      ]
    }
  },
  'applet': {
    'code': {
      name: '规定 Java applet 的文件名',
      tips: [{ value: 'URL', label: '文件路径' }]
    },
    'object': {
      name: '定义了包含该 applet 的一系列版本的资源名称',
      tips: [{ value: 'name', label: '资源名称' }]
    },
    'align': {
      name: '定义 applet 相对于周围元素的对齐方式',
      tips: [{ value: 'left', label: '左对齐' },
        { value: 'right', label: '右对齐' },
        { value: 'top', label: '上对齐' },
        { value: 'bottom', label: '下对齐' },
        { value: 'middle', label: '居中对齐' },
        { value: 'baseline', label: '基线对齐' },
        { value: 'texttop', label: '文字上边线对齐' },
        { value: 'absmiddle', label: '绝对置中' },
        { value: 'absbottom', label: '绝对置底' }
      ]
    },
    'alt': {
      name: '规定 applet 的替换文本',
      tips: [{ value: 'text', label: '文本' }]
    },
    'archive': {
      name: '规定档案文件的位置',
      tips: [{ value: 'URL', label: '文件路径' }]
    },
    'codebase': {
      name: '规定 code 属性中指定的 applet 的基准 URL',
      tips: [{ value: 'URL', label: '基准路径' }]
    },
    'height': {
      name: '定义 applet 的高度',
      tips: [{ value: '10px', label: '设置为一个固定得值' }]
    },
    'hspace': {
      name: '定义围绕 applet 的水平间隔',
      tips: [{ value: '10px', label: '设置为一个固定得值' }]
    },
    'name': {
      name: '规定 applet 的名称（用在脚本中的）',
      tips: [{ value: 'unique_name', label: '名称' }]
    },
    'vspace': {
      name: '定义围绕 applet 的垂直间隔',
      tips: [{ value: '10px', label: '设置为一个固定得值' }]
    },
    'width': {
      name: '定义 applet 的宽度',
      tips: [{ value: '10px', label: '设置为一个固定得值' }]
    }
  },
  'area': {
    'alt': {
      name: '定义此区域的替换文本',
      tips: [{ value: 'text', label: '文本' }]
    },
    'coords': {
      name: '定义可点击区域（对鼠标敏感的区域）的坐标',
      tips: [
        { value: 'x1,y1,x2,y2', label: '如果 shape 属性设置为 "rect"，则该值规定矩形左上角和右下角的坐标' },
        { value: 'x,y,radius', label: '如果 shape 属性设置为 "circ"，则该值规定圆心的坐标和半径' },
        {
          value: 'x1,y1,x2,y2,..,xn,yn',
          label: '如果 shape 属性设置为 "poly"，则该值规定多边形各边的坐标。如果第一个坐标和最后一个坐标不一致，那么为了关闭多边形，浏览器必须添加最后一对坐标'
        }
      ]
    },
    'href': {
      name: '定义此区域的目标 URL',
      tips: [{ value: 'URL', label: '链接的路径' }]
    },
    'nohref': {
      name: '从图像映射排除某个区域',
      tips: [{ value: 'nohref', label: '规定区域没有相关的链接' }]
    },
    'shape': {
      name: '规定链接的形状',
      tips: [{ value: 'default', label: '规定全部区域' },
        { value: 'rect', label: '定义矩形区域' },
        { value: 'circle', label: '定义圆形' },
        { value: 'poly', label: '定义多边形区域' }
      ]
    },
    'target': {
      name: '规定链接的形状',
      tips: [{ value: '_blank', label: '在新窗口中打开被链接文档' },
        { value: '_self', label: '默认。在相同的框架中打开被链接文档' },
        { value: '_parent', label: '在父框架集中打开被链接文档' },
        { value: '_top', label: '在整个窗口中打开被链接文档' },
        { value: 'framename', label: '在指定的框架中打开被链接文档' }
      ]
    }
  },
  'audio': {
    'autoplay': {
      name: '如果出现该属性，则音频在就绪后马上播放',
      tips: [{ value: 'autoplay', label: '自动播放' }]
    },
    'controls': {
      name: '如果出现该属性，则向用户显示控件，比如播放按钮',
      tips: [{ value: 'controls', label: '控制播放' }]
    },
    'loop': {
      name: '如果出现该属性，则每当音频结束时重新开始播放',
      tips: [{ value: 'loop', label: '循环播放' }]
    },
    'muted': {
      name: '规定视频输出应该被静音',
      tips: [{ value: 'muted', label: '静音播放' }]
    },
    'preload': {
      name: '如果出现该属性，则音频在页面加载时进行加载，并预备播放。如果使用 "autoplay"，则忽略该属性',
      tips: [
        { value: 'load', label: '规定是否预加载音频' },
        { value: 'auto', label: '当页面加载后载入整个音频' },
        { value: 'meta', label: '当页面加载后只载入元数据' },
        { value: 'none', label: '当页面加载后不载入音频' }
      ]
    },
    'src': {
      name: '要播放的音频的 URL',
      tips: [{ value: 'url', label: '路径' }]
    }
  },
  'base': {
    'href': {
      name: '规定页面中所有相对链接的基准 URL',
      tips: [{ value: 'URL', label: '作为基准 URL 的绝对 URL（比如 "http://www.example.com/"）' }]
    },
    'target': {
      name: '规定链接的形状',
      tips: [{ value: '_blank', label: '在新窗口中打开被链接文档' },
        { value: '_self', label: '默认。在相同的框架中打开被链接文档' },
        { value: '_parent', label: '在父框架集中打开被链接文档' },
        { value: '_top', label: '在整个窗口中打开被链接文档' },
        { value: 'framename', label: '在指定的框架中打开被链接文档' }
      ]
    }
  },
  'bdi': {
    'dir': {
      name: '规定元素内的文本的文本方向。默认值：auto',
      tips: [
        { value: 'auto', label: '默认值' },
        { value: 'ltr', label: '文本从左向右正常方向' },
        { value: 'rtl', label: '文本从右向左' }
      ]
    }
  },
  'bdo': {
    'dir': {
      name: '定义文字方向',
      tips: [
        { value: 'ltr', label: '文本从左向右正常方向' },
        { value: 'rtl', label: '文本从右向左' }
      ]
    }
  },
  'blockquote': {
    'cite ': {
      name: '规定引用的来源',
      tips: [{ value: 'URL', label: '引用的来源的路径' }]
    }
  },
  'body': {
    'alink': {
      name: '规定文档中活动链接（active link）的的颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的字体颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的字体颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的字体颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'background': {
      name: '规定文档的背景图像(不推荐)',
      tips: [{ value: 'URL', label: '背景图像的路径' }]
    },
    'bgcolor': {
      name: '规定文档的背景图像(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的字体颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的字体颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的字体颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'link': {
      name: '规定文档中未访问链接的默认颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的字体颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的字体颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的字体颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'text': {
      name: '规定文档中所有文本的颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的字体颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的字体颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的字体颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'vlink': {
      name: '规定文档中已被访问链接的颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的字体颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的字体颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的字体颜色（比如 "rgb(255,0,0)"）' }
      ]
    }
  },
  'button': {
    'autofocus': {
      name: '规定当页面加载时按钮应当自动地获得焦点',
      tips: [{ value: 'autofocus', label: '自动对焦' }]
    },
    'disabled': {
      name: '规定应该禁用该按钮',
      tips: [{ value: 'disabled', label: '禁用' }]
    },
    'form': {
      name: '规定按钮属于一个或多个表单',
      tips: [{ value: 'form_name', label: '自定义名称' }]
    },
    'formaction': {
      name: '覆盖 form 元素的 action 属性。注释：该属性与 type="submit" 配合使用',
      tips: [{ value: 'url', label: '路径' }]
    },
    'formenctype': {
      name: '覆盖 form 元素的 enctype 属性。注释：该属性与 type="submit" 配合使用',
      tips: [
        { value: 'application/x-www-form-urlencoded', label: '在发送前对所有字符进行编码（默认）' },
        { value: 'multipart/form-data', label: '不对字符编码。当使用有文件上传控件的表单时，该值是必需的' },
        { value: 'text/plain', label: '将空格转换为 "+" 符号，但不编码特殊字符' }
      ]
    },
    'formmethod': {
      name: '覆盖 form 元素的 method 属性。注释：该属性与 type="submit" 配合使用',
      tips: [
        { value: 'get', label: '向 URL 追加表单数据（form-data）：URL?name=value&name=value' },
        { value: 'post', label: '以 HTTP post 事务的形式发送表单数据（form-data）' }
      ]
    },
    'formnovalidate': {
      name: '覆盖 form 元素的 novalidate 属性。注释：该属性与 type="submit" 配合使用',
      tips: [
        { value: 'formnovalidate', label: '覆盖 form 元素的 novalidate 属性' }
      ]
    },
    'formtarget': {
      name: '覆盖 form 元素的 target 属性。注释：该属性与 type="submit" 配合使用',
      tips: [
        { value: '_blank', label: '在新窗口/选项卡中将表单提交到文档' },
        { value: '_self', label: '在同一框架中将表单提交到文档。（默认）' },
        { value: '_parent', label: '在父框架中将表单提交到文档' },
        { value: '_top', label: '在整个窗口中将表单提交到文档' },
        { value: 'framename', label: '在指定的框架中将表单提交到文档' }
      ]
    },
    'name': {
      name: '规定按钮的名称',
      tips: [{ value: 'button_name', label: '自定义名称' }]
    },
    'type': {
      name: '规定按钮的名称',
      tips: [
        { value: 'submit', label: '该按钮是提交按钮' },
        { value: 'button', label: '该按钮是可点击的按钮' },
        { value: 'reset', label: '该按钮是重置按钮' }
      ]
    },
    'value': {
      name: '规定按钮的初始值。可由脚本进行修改',
      tips: [{ value: 'value', label: '规定要发送的值' }]
    }
  },
  'canvas': {
    'height': {
      name: '设置 canvas 的高度，默认是 "150"',
      tips: [{ value: '10px', label: '自定义固定值' }]
    },
    'width': {
      name: '设置 canvas 的宽度，默认是 "150"',
      tips: [{ value: '10px', label: '自定义固定值' }]
    }
  },
  'caption': {
    'align': {
      name: '规定标题的对齐方式(不推荐)',
      tips: [
        { value: 'left', label: '左对齐' },
        { value: 'right', label: '右对齐' },
        { value: 'top', label: '上对齐' },
        { value: 'bottom', label: '下对齐' }
      ]
    }
  },
  'col': {
    'align': {
      name: '规定与 col 元素相关的内容的水平对齐方式',
      tips: [
        { value: 'left', label: '左对齐内容（默认值）' },
        { value: 'right', label: '右对齐内容' },
        { value: 'center', label: '居中对齐内容（th 元素的默认值）' },
        { value: 'justify', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' },
        { value: 'char', label: '将内容对准指定字符' }
      ]
    },
    'char': {
      name: '规定根据哪个字符来对齐与 col 元素相关的内容，仅当 align 属性设置为 "char" 时，才能使用',
      tips: [
        { value: 'character', label: '规定将内容与之对齐的字符' }
      ]
    },
    'charoff': {
      name: '规定第一个对齐字符的偏移量，仅当 align 属性设置为 "char" 时，才能使用',
      tips: [
        { value: '2', label: '规定对齐方式。' },
        { value: 'number', label: '规定对齐方式。正数规定向字符的右边对齐。负数规定向字符的左边对齐' }
      ]
    },
    'span': {
      name: '规定 col 元素应该横跨的列数',
      tips: [
        { value: 'number', label: '设置 col 元素应该横跨的列数' },
        { value: '2', label: '横跨2列' },
        { value: '3', label: '横跨3列' },
        { value: '6', label: '横跨6列' }
      ]
    },
    'valign': {
      name: '定义与 col 元素相关的内容的垂直对齐方式',
      tips: [
        { value: 'top', label: '对内容进行上对齐' },
        { value: 'middle', label: '对内容进行居中对齐（默认值）' },
        { value: 'bottom', label: '对内容进行下对齐' },
        { value: 'baseline', label: '与基线对齐' }
      ]
    },
    'width': {
      name: '定义与 col 元素相关的内容的垂直对齐方式',
      tips: [
        { value: 'pixels', label: '设置以像素计的宽度值（例子：width="50"）' },
        { value: 'percent', label: '设置以包围元素的百分比计的宽度值（例子：width="50%"）' },
        { value: 'relative_length', label: '把可用像素分配到各部分' }
      ]
    }
  },
  'colgroup': {
    'align': {
      name: '定义在列组合中内容的水平对齐方式',
      tips: [
        { value: 'left', label: '左对齐内容（默认值）' },
        { value: 'right', label: '右对齐内容' },
        { value: 'center', label: '居中对齐内容（th 元素的默认值）' },
        { value: 'justify', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' },
        { value: 'char', label: '将内容对准指定字符' }
      ]
    },
    'char': {
      name: '规定根据哪个字符来对齐列组中的内容，仅当 align 属性设置为 "char" 时，才能使用',
      tips: [
        { value: '2', label: '规定对齐方式。' },
        { value: 'character', label: '规定将内容与之对齐的字符' }
      ]
    },
    'charoff': {
      name: '规定第一个对齐字符的偏移量，仅当 align 属性设置为 "char" 时，才能使用',
      tips: [
        { value: 'number', label: '规定对齐方式。正数规定向字符的右边对齐。负数规定向字符的左边对齐' }
      ]
    },
    'span': {
      name: '规定列组应该横跨的列数',
      tips: [
        { value: 'number', label: '设置 col 元素应该横跨的列数' },
        { value: '2', label: '横跨2列' },
        { value: '3', label: '横跨3列' },
        { value: '6', label: '横跨6列' }
      ]
    },
    'valign': {
      name: '定义在列组合中内容的垂直对齐方式',
      tips: [
        { value: 'top', label: '对内容进行上对齐' },
        { value: 'middle', label: '对内容进行居中对齐（默认值）' },
        { value: 'bottom', label: '对内容进行下对齐' },
        { value: 'baseline', label: '与基线对齐' }
      ]
    },
    'width': {
      name: '规定列组合的宽度',
      tips: [
        { value: 'pixels', label: '设置以像素计的宽度值（例子：width="50"）' },
        { value: 'percent', label: '设置以包围元素的百分比计的宽度值（例子：width="50%"）' },
        { value: 'relative_length', label: '把可用像素分配到各部分' }
      ]
    }
  },
  // 只有 Internet Explorer 9 支持（更早或更晚的版本都不支持）
  'command': {
    'checked': {
      name: '定义是否被选中。仅用于 radio 或 checkbox 类型',
      tips: [
        { value: 'checked', label: '规定应该预先选择该命令（适用于 checkbox 或 radio）' }
      ]
    },
    'disabled': {
      name: '定义 command 是否可用',
      tips: [
        { value: 'disabled', label: '规定应该禁用 command 元素' }
      ]
    },
    'icon': {
      name: '定义作为 command 来显示的图像的 url',
      tips: [
        { value: 'URL', label: '规定用于代表命令的图像的路径' }
      ]
    },
    'label': {
      name: '为 command 定义可见的 label',
      tips: [
        { value: 'checked', label: '规定命令的可见标签' }
      ]
    },
    'radiogroup': {
      name: '定义 command 所属的组名。仅在类型为 radio 时使用',
      tips: [
        { value: 'groupname', label: '规定将被切换的命令组的名称（仅适用于 type="radio"）' }
      ]
    },
    'type': {
      name: '规定列组合的宽度',
      tips: [
        { value: 'command', label: '默认。规定带有 action 的普通 command' },
        { value: 'checkbox', label: '规定可切换的选项' },
        { value: 'radio', label: '规定列表中的单项的选择' }
      ]
    }
  },
  'del': {
    'cite': {
      name: '指向另外一个文档的 URL，此文档可解释文本被删除的原因',
      tips: [
        { value: 'URL', label: '文档的地址，该文档解释了文本被删除的原因' }
      ]
    },
    'datetime': {
      name: '定义文本被删除的日期和时间',
      tips: [
        { value: 'YYYY-MM-DDThh:mm:ssTZD', label: '文本被删除的日期和时间' }
      ]
    }
  },
  'details': {
    'open': {
      name: '定义 details 是否可见',
      tips: [
        { value: 'open', label: '规定在 HTML 页面上 details 应该是可见的' }
      ]
    }
  },
  'dialog': {
    'open': {
      name: '规定 dialog 元素是活动的，用户可与之交互',
      tips: [
        { value: 'open', label: '规定在 HTML 页面上 details 应该是可见的' }
      ]
    }
  },
  'div': {
    'id': {
      name: '规定元素的唯一 id',
      tips: [
        { value: 'id', label: '规定元素的唯一 id' }
      ]
    },
    'align': {
      name: '规定 div 元素中的内容的对齐方式(不推荐)',
      tips: [
        { value: 'left', label: '左对齐内容' },
        { value: 'right', label: '右对齐内容' },
        { value: 'center', label: '居中对齐内容' },
        { value: 'justify', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' }
      ]
    },
    'accesskey': {
      name: '规定激活元素的快捷键',
      tips: [
        { value: 'character', label: '规定激活（使元素获得焦点）元素的便捷按键' }
      ]
    },
    'contenteditable': {
      name: '规定元素内容是否可编辑',
      tips: [
        { value: 'true', label: '规定元素可编辑' },
        { value: 'false', label: '规定元素不可编辑' }
      ]
    },
    'dir': {
      name: '规定元素中内容的文本方向',
      tips: [
        { value: 'ltr', label: '默认。从左向右的文本方向' },
        { value: 'rtl', label: '从右向左的文本方向' }
      ]
    },
    'draggable': {
      name: '规定元素是否可拖动',
      tips: [
        { value: 'true', label: '规定元素的可拖动的' },
        { value: 'false', label: '规定元素不可拖动' },
        { value: 'auto', label: '使用浏览器的默认行为' }
      ]
    },
    'hidden': {
      name: '规定元素是否隐藏',
      tips: [
        { value: 'hidden', label: '规定元素被隐藏' }
      ]
    },
    'lang': {
      name: '规定元素是否隐藏',
      tips: [
        { value: 'zh', label: '中文(简体)' },
        { value: 'en', label: '英文' },
        { value: 'ja', label: '日语' },
        { value: 'ko', label: '韩语' },
        { value: 'https://www.w3school.com.cn/tags/html_ref_language_codes.asp', label: '语言对照表' }
      ]
    },
    'tabindex': {
      name: '规定元素的 tab 键次序',
      tips: [
        { value: '1', label: '第一次按tab切换到' },
        { value: '2', label: '第二次按tab切换到' },
        { value: 'number', label: '规定元素的 tab 键控制次序（1 是第一个）' }
      ]
    },
    'title': {
      name: '规定有关元素的额外信息',
      tips: [
        { value: 'title', label: '元素的额外信息' }
      ]
    },
    'translate': {
      name: '规定是否应该翻译元素内容',
      tips: [
        { value: 'yes', label: '规定应该翻译元素内容' },
        { value: 'no', label: '规定不应翻译元素内容' }
      ]
    }
  },
  'embed': {
    'height': {
      name: '设置嵌入内容的高度',
      tips: [{ value: 'pixels', label: '规定被嵌入内容的高度，以像素计（比如 "100px" 或 just "100"）' }]
    },
    'src': {
      name: '嵌入内容的 URL',
      tips: [{ value: 'URL', label: '被嵌入内容的路径' }]
    },
    'type': {
      name: '定义嵌入内容的类型',
      tips: [
        { value: 'text/html', label: '超文本标记语言文本(.html，.htm)' },
        { value: 'text/plain', label: '普通文本(.txt)' },
        { value: 'image/gif', label: 'GIF图形(.gif)' },
        { value: 'image/jpeg', label: 'JPEG图形(.jpeg，.jpg)' },
        { value: 'text/css', label: '层叠样式文本(.css)' },
        { value: 'audio/mpeg', label: '音频文件(.mp3)' },
        { value: 'application/pdf', label: '便携式文档格式(.pdf)' },
        { value: 'application/msword', label: 'Word文档(.doc)' },
        { value: 'application/zip', label: '压缩文件(.zip)' },
        { value: 'application/octet-stream', label: '下载文件类型(.exe)' },
        { value: 'text/javascript', label: 'javascript' }
      ]
    },
    'width': {
      name: '设置嵌入内容的宽度',
      tips: [{ value: 'pixels', label: '规定被嵌入内容的宽度，以像素计（比如 "100px" 或 just "100"）' }]
    }
  },
  'fieldset': {
    'disabled': {
      name: '规定应该禁用 fieldset',
      tips: [{ value: 'disabled', label: '规定应该禁用表单元素组合 (fieldset)' }]
    },
    'form': {
      name: '规定 fieldset 所属的一个或多个表单',
      tips: [{ value: 'form_id', label: 'fieldset 所属表单 id 的空格分隔列表' }]
    },
    'name': {
      name: '规定 fieldset 的名称',
      tips: [{ value: 'name', label: 'fieldset 的名称' }]
    }
  },
  'font': {
    'color': {
      name: '规定文本的颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的文本颜色（比如 "red"' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的文本颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的文本颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'face': {
      name: '规定文本的字体(不推荐)',
      tips: [
        { value: 'verdana', label: '' },
        { value: 'arial', label: '' },
        { value: 'sans-serif', label: '' },
        { value: 'font_family', label: '规定文本的字体。如需规定若干字体的优先表，请使用逗号将字体名称分开' }
      ]
    },
    'size': {
      name: '规定文本的大小(不推荐)',
      tips: [
        { value: 'number', label: '规定文本的尺寸大小。可能的值：从 1 到 7 的数字。浏览器默认值是 3' },
        { value: '1', label: '' },
        { value: '2', label: '' }
      ]
    }
  },
  'form': {
    'accept-charset': {
      name: '规定服务器可处理的表单数据字符集',
      tips: [
        { value: 'character_set', label: '服务器可处理的一个或多个字符集。如需规定一个以上的字符集，请使用逗号来分隔各字符集' },
        { value: 'UTF-8', label: 'Unicode字符编码' },
        { value: 'ISO-8859-1', label: '拉丁字母表的编码' },
        { value: 'GB2312', label: '简体汉字编码' }
      ]
    },
    'action': {
      name: '规定当提交表单时向何处发送表单数据',
      tips: [{ value: 'URL', label: '向何处发送表单数据' }]
    },
    'autocomplete': {
      name: '规定是否启用表单的自动完成功能',
      tips: [
        { value: 'on', label: '默认。规定启用自动完成功能' },
        { value: 'off', label: '规定禁用自动完成功能' }
      ]
    },
    'enctype': {
      name: '规定在发送表单数据之前如何对其进行编码',
      tips: [
        { value: 'application/x-www-form-urlencoded', label: '在发送前编码所有字符（默认）' },
        { value: 'multipart/form-data', label: '不对字符编码。在使用包含文件上传控件的表单时，必须使用该值' },
        { value: 'text/plain', label: '空格转换为 "+" 加号，但不对特殊字符编码' }
      ]
    },
    'method': {
      name: '规定用于发送 form-data 的 HTTP 方法',
      tips: [
        { value: 'post', label: '首先，浏览器将与 action 属性中指定的表单处理服务器建立联系，一旦建立连接之后，浏览器就会按分段传输的方法将数据发送给服务器。在服务器端，一旦 POST 样式的应用程序开始执行时，就应该从一个标志位置读取参数，而一旦读到参数，在应用程序能够使用这些表单值以前，必须对这些参数进行解码。用户特定的服务器会明确指定应用程序应该如何接受这些参数' },
        { value: 'get', label: '浏览器会与表单处理服务器建立连接，然后直接在一个传输步骤中发送所有的表单数据：浏览器会将数据直接附在表单的 action URL 之后。这两者之间用问号进行分隔' }
      ]
    },
    'name': {
      name: '规定表单的名称',
      tips: [{ value: 'name', label: '表单的名称' }]
    },
    'novalidate': {
      name: '如果使用该属性，则提交表单时不进行验证',
      tips: [{ value: 'novalidate', label: '当提交表单时不对其进行验证' }]
    },
    'target': {
      name: '规定在何处打开 action URL',
      tips: [{ value: '_blank', label: '在新窗口中打开' },
        { value: '_self', label: '默认。在相同的框架中打开' },
        { value: '_parent', label: '在父框架集中打开' },
        { value: '_top', label: '在整个窗口中打开被' },
        { value: 'framename', label: '在指定的框架中打开' }
      ]
    }
  },
  'frame': {
    'frameborder': {
      name: '规定是否显示框架周围的边框',
      tips: [
        { value: '1', label: '有边框（默认值）' },
        { value: '0', label: '无边框' }
      ]
    },
    'longdesc': {
      name: '规定一个包含有关框架内容的长描述的页面',
      tips: [{ value: 'URL', label: '规定框架的内容描述页面的 URL' }]
    },
    'marginheight': {
      name: '定义框架的上方和下方的边距',
      tips: [
        { value: 'pixels', label: '规定框架的上边距和下边距' },
        { value: '10px', label: '' }
      ]
    },
    'marginwidth': {
      name: '定义框架的左侧和右侧的边距',
      tips: [
        { value: 'pixels', label: '规定框架的左边距和右边距' },
        { value: '10px', label: '' }
      ]
    },
    'name': {
      name: '规定框架的名称',
      tips: [{ value: 'name', label: '框架的名称' }]
    },
    'noresize': {
      name: '规定无法调整框架的大小',
      tips: [{ value: 'noresize', label: '用户无法调整框架的大小' }]
    },
    'scrolling': {
      name: '规定是否在框架中显示滚动条',
      tips: [
        { value: 'auto', label: '在需要的时候显示滚动条' },
        { value: 'yes', label: '始终显示滚动条（即使不需要）' },
        { value: 'no', label: '从不显示滚动条（即使需要）' }
      ]
    },
    'src': {
      name: '规定在框架中显示的文档的 URL',
      tips: [{ value: 'URL', label: '规定要在框架中显示的文档的地址' }]
    }
  },
  'frameset': {
    'cols': {
      name: '定义框架集中列的数目和尺寸',
      tips: [
        { value: 'pixels', label: '规定尺寸，以像素计（比如 "100px" 或 just "100"）' },
        { value: '%', label: '设置元素的百分比计的值（例子：width="50%"）' },
        { value: '*', label: '要在将相邻的框架放入框架集之后，给剩下的空间分配各自的行或列' }
      ]
    },
    'rows': {
      name: '定义框架集中行的数目和尺寸',
      tips: [
        { value: 'pixels', label: '规定尺寸，以像素计（比如 "100px" 或 just "100"）' },
        { value: '%', label: '设置元素的百分比计的值（例子：width="50%"）' },
        { value: '*', label: '要在将相邻的框架放入框架集之后，给剩下的空间分配各自的行或列' }
      ]
    }
  },
  '<h1>-<h6>': {
    'align': {
      name: '规定标题中文本的排列(不推荐)',
      tips: [
        { value: 'left', label: '左对齐内容' },
        { value: 'right', label: '右对齐内容' },
        { value: 'center', label: '居中对齐内容' },
        { value: 'justify', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' }
      ]
    }
  },
  'head': {
    'profile': {
      name: '一个由空格分隔的 URL 列表，这些 URL 包含着有关页面的元数据信息',
      tips: [
        { value: 'URL', label: '路径' }
      ]
    }
  },
  'hr': {
    'align': {
      name: '规定 hr 元素的对齐方式(不推荐)',
      tips: [
        { value: 'left', label: '左对齐水平线' },
        { value: 'right', label: '右对齐水平线（默认值）' },
        { value: 'center', label: '居中对齐水平线' }
      ]
    },
    'noshade': {
      name: '规定 hr 元素的颜色呈现为纯色(不推荐)',
      tips: [
        { value: 'noshade', label: '规定水平线的颜色呈现为纯色（没有阴影）' }
      ]
    },
    'size': {
      name: '规定 hr 元素的高度（厚度）(不推荐)',
      tips: [
        { value: 'pixels', label: '规定 hr 元素的高度' },
        { value: '10px', label: '10px' }
      ]
    },
    'width': {
      name: '规定 hr 元素的宽度(不推荐)',
      tips: [
        { value: 'pixels', label: '规定以像素计的宽度（比如 "50px" 或者仅仅是 "50"）' },
        { value: '%', label: '规定以可用空间的百分比计的宽度（比如 "50%"）' },
        { value: '100px', label: '100px' },
        { value: '50%', label: '50%' }
      ]
    }
  },
  'html': {
    'manifest': {
      name: '定义一个 URL，在这个 URL 上描述了文档的缓存信息',
      tips: [
        { value: 'url', label: '路径' }
      ]
    },
    'xmlns': {
      name: '定义 XML namespace 属性',
      tips: [
        { value: 'http://www.w3.org/1999/xhtml', label: '值类似于 URL，它定义了一个命名空间，浏览器会将此命名空间用于该属性所在元素内的所有内容' }
      ]
    }
  },
  'iframe': {
    'align': {
      name: '规定如何根据周围的元素来对齐此框架(不推荐)',
      tips: [
        { value: 'left', label: '向左对齐 iframe' },
        { value: 'right', label: '向右对齐 iframe' },
        { value: 'middle', label: '居中对齐 iframe' },
        { value: 'top', label: '在顶部对齐 iframe' },
        { value: 'bottom', label: '在底部对齐 iframe' }
      ]
    },
    'frameborder': {
      name: '规定是否显示框架周围的边框',
      tips: [
        { value: '1', label: '有边框（默认值）' },
        { value: '0', label: '无边框' }
      ]
    },
    'height': {
      name: '规定 iframe 的高度',
      tips: [
        { value: 'pixels', label: '以像素计的高度值（比如 "100px"）' },
        { value: 'percent', label: '以包含元素百分比计的高度值（比如 "20%"）' },
        { value: '100px', label: '100px' },
        { value: '50%', label: '50%' }
      ]
    },
    'longdesc': {
      name: '规定一个页面，该页面包含了有关 iframe 的较长描述',
      tips: [
        { value: 'URL', label: '规定 iframe 的内容描述页面的 URL' }
      ]
    },
    'marginheight': {
      name: '定义 iframe 的顶部和底部的边距',
      tips: [
        { value: 'pixels', label: '规定 iframe 的顶部和底部的空白边距，以像素计' },
        { value: '20px', label: '20px' }
      ]
    },
    'marginwidth': {
      name: '定义 iframe 的左侧和右侧的边距',
      tips: [
        { value: 'pixels', label: '规定 iframe 的左边和右边的空白边距，以像素计' },
        { value: '50px', label: '50px' }
      ]
    },
    'name': {
      name: '规定 iframe 的名称',
      tips: [
        { value: 'name', label: '规定 iframe 的名称' }
      ]
    },
    'sandbox': {
      name: '启用一系列对内容的额外限制',
      tips: [
        { value: '""', label: '应用以下所有的限制' },
        { value: 'allow-same-origin', label: '允许 iframe 内容被视为与包含文档有相同的来源' },
        { value: 'allow-top-navigation', label: '允许 iframe 内容从包含文档导航（加载）内容' },
        { value: 'allow-forms', label: '允许表单提交' },
        { value: 'allow-scripts', label: '允许脚本执行' }
      ]
    },
    'scrolling': {
      name: '规定是否在 iframe 中显示滚动条',
      tips: [
        { value: 'auto', label: '在需要的情况下出现滚动条（默认值）' },
        { value: 'yes', label: '始终显示滚动条（即使不需要）' },
        { value: 'no', label: '从不显示滚动条（即使需要）' }
      ]
    },
    'seamless': {
      name: '规定 iframe 看上去像是包含文档的一部分',
      tips: [
        { value: 'seamless', label: '当设置该属性后，它规定了看上去像是包含文档的一部分（无边框或滚动条）' }
      ]
    },
    'src': {
      name: '规定在 iframe 中显示的文档的 URL',
      tips: [
        { value: 'URL', label: '规定显示在 iframe 中的文档的地址' }
      ]
    },
    'srcdoc': {
      name: '规定在 iframe 中显示的页面的 HTML 内容',
      tips: [
        { value: 'URL', label: '规定显示在 iframe 中的文档的地址' }
      ]
    },
    'width': {
      name: '定义 iframe 的宽度',
      tips: [
        { value: 'pixels', label: '以像素计的宽度值（比如 "100px"）' },
        { value: 'percent', label: '以包含元素百分比计的宽度值（比如 "20%"）' },
        { value: '100px', label: '100px' },
        { value: '50%', label: '50%' }
      ]
    }
  },
  'img': {
    'alt': {
      name: '规定图像的替代文本',
      tips: [
        { value: 'text', label: '规定图像的替代文本' }
      ]
    },
    'src': {
      name: '规定显示图像的 URL',
      tips: [
        { value: 'URL', label: '规定图像的 URL' }
      ]
    },
    'align': {
      name: '规定如何根据周围的文本来排列图像(不推荐)',
      tips: [
        { value: 'left', label: '把图像对齐到左边' },
        { value: 'right', label: '把图像对齐到右边' },
        { value: 'middle', label: '把图像与中央对齐' },
        { value: 'top', label: '把图像与顶部对齐' },
        { value: 'bottom', label: '把图像与底部对齐' }
      ]
    },
    'border': {
      name: '定义图像周围的边框(不推荐)',
      tips: [
        { value: 'pixels', label: '边框的宽度，以像素为单位' },
        { value: '10px', label: '10px' }
      ]
    },
    'height': {
      name: '定义图像的高度',
      tips: [
        { value: 'pixels', label: '以像素为单位的高度或宽度值' },
        { value: 'percent', label: '以包含元素的百分比计的高度或宽度值' },
        { value: '20px', label: '20px' },
        { value: '10%', label: '10%' }
      ]
    },
    'hspace': {
      name: '定义图像左侧和右侧的空白(不推荐)',
      tips: [
        { value: 'pixels', label: '以像素为单位的图像周围的空白' }
      ]
    },
    'longdesc': {
      name: '指向包含长的图像描述文档的 URL',
      tips: [
        { value: 'URL', label: '指向图像描述页面的 URL' }
      ]
    },
    'usemap': {
      name: '将图像定义为客户器端图像映射',
      tips: [
        { value: '#mapname', label: '# + 要使用的 map 元素的 name 或 id 属性' }
      ]
    },
    'vspace': {
      name: '定义图像顶部和底部的空白(不推荐)',
      tips: [
        { value: 'pixels', label: '以像素为单位的图像周围的空白' },
        { value: '10px', label: '10px' }
      ]
    },
    'width': {
      name: '设置图像的宽度',
      tips: [
        { value: 'pixels', label: '以像素为单位的高度或宽度值' },
        { value: 'percent', label: '以包含元素的百分比计的高度或宽度值' },
        { value: '100px', label: '100px' },
        { value: '50%', label: '50%' }
      ]
    }
  },
  'input': {
    'accept': {
      name: '规定通过文件上传来提交的文件的类型',
      tips: [
        { value: 'text/html', label: '超文本标记语言文本(.html，.htm)' },
        { value: 'text/plain', label: '普通文本(.txt)' },
        { value: 'image/gif', label: 'GIF图形(.gif)' },
        { value: 'image/jpeg', label: 'JPEG图形(.jpeg，.jpg)' },
        { value: 'text/css', label: '层叠样式文本(.css)' },
        { value: 'audio/mpeg', label: '音频文件(.mp3)' },
        { value: 'application/pdf', label: '便携式文档格式(.pdf)' },
        { value: 'application/msword', label: 'Word文档(.doc)' },
        { value: 'application/zip', label: '压缩文件(.zip)' },
        { value: 'application/octet-stream', label: '下载文件类型(.exe)' },
        { value: 'text/javascript', label: 'javascript' }
      ]
    },
    'align': {
      name: '规定图像输入的对齐方式(不推荐)',
      tips: [
        { value: 'left', label: '左对齐图像（默认）' },
        { value: 'right', label: '右对齐对象' },
        { value: 'top', label: '上对齐图像' },
        { value: 'middle', label: '居中对齐图像' },
        { value: 'bottom', label: '下对齐图像' }
      ]
    },
    'alt': {
      name: '定义图像输入的替代文本',
      tips: [{ value: 'value', label: '图像 input 的替代文本' }]
    },
    'autocomplete': {
      name: '规定是否使用输入字段的自动完成功能',
      tips: [
        { value: 'on', label: '默认。规定启用自动完成功能' },
        { value: 'off', label: '规定禁用自动完成功能' }
      ]
    },
    'autofocus': {
      name: '规定输入字段在页面加载时是否获得焦点。（不适用于 type="hidden"）',
      tips: [{ value: 'autofocus', label: '获取焦点' }]
    },
    'checked': {
      name: '规定此 input 元素首次加载时应当被选中',
      tips: [{ value: 'checked', label: '预先选定复选框或单选按钮' }]
    },
    'disabled': {
      name: '当 input 元素加载时禁用此元素',
      tips: [{ value: 'disabled', label: '禁用一个 input 元素' }]
    },
    'form': {
      name: '规定输入字段所属的一个或多个表单',
      tips: [{ value: 'id', label: 'input 元素所属的一个或多个表单的 id' }]
    },
    'formaction': {
      name: '覆盖表单的 action 属性。（适用于 type="submit" 和 type="image"）',
      tips: [{ value: 'URL', label: '向何处发送表单数据' }]
    },
    'formenctype': {
      name: '覆盖表单的 enctype 属性。（适用于 type="submit" 和 type="image"）',
      tips: [
        { value: 'application/x-www-form-urlencoded', label: '在发送前对所有字符进行编码（默认）' },
        { value: 'multipart/form-data', label: '不对字符编码。当使用有文件上传控件的表单时，该值是必需的' },
        { value: 'text/plain', label: '将空格转换为 "+" 符号，但不编码特殊字符' }
      ]
    },
    'formmethod': {
      name: '覆盖表单的 method 属性。（适用于 type="submit" 和 type="image"）',
      tips: [
        { value: 'get', label: '向 URL 追加表单数据（form-data）：URL?name=value&name=value' },
        { value: 'post', label: '以 HTTP post 事务的形式发送表单数据（form-data）' }
      ]
    },
    'formnovalidate': {
      name: '覆盖表单的 novalidate 属性',
      tips: [{ value: 'formnovalidate', label: '如果使用该属性，则提交表单时不进行验证' }]
    },
    'formtarget': {
      name: '覆盖表单的 target 属性。（适用于 type="submit" 和 type="image"）',
      tips: [
        { value: '_blank', label: '在新窗口/选项卡中将表单提交到文档' },
        { value: '_self', label: '在同一框架中将表单提交到文档。（默认）' },
        { value: '_parent', label: '在父框架中将表单提交到文档' },
        { value: '_top', label: '在整个窗口中将表单提交到文档' },
        { value: 'framename', label: '在指定的框架中将表单提交到文档' }
      ]
    },
    'height': {
      name: '定义 input 字段的高度。（适用于 type="image"）',
      tips: [
        { value: 'pixels', label: '以像素计的高度。（比如 "100px" 或仅仅是 "100"）' },
        { value: '%', label: '以包含元素的百分比计的高度（比如 "50%"）' },
        { value: '100px', label: '100px' },
        { value: '50%', label: '50%' }
      ]
    },
    'list': {
      name: '引用包含输入字段的预定义选项的 datalist',
      tips: [{ value: 'datalist-id', label: '文档中的 datalist 的 id' }]
    },
    'max': {
      name: '规定输入字段的最大值。请与 "min" 属性配合使用，来创建合法值的范围',
      tips: [
        { value: 'number', label: '数字值。规定输入字段允许的最大值' },
        { value: 'date', label: '日期。规定输入字段允许的最大值' }
      ]
    },
    'maxlength': {
      name: '规定输入字段中的字符的最大长度',
      tips: [
        { value: 'characters', label: '输入字段中允许的最大字符数' },
        { value: '10', label: '输入最大长度为10' },
        { value: '20', label: '输入最大长度为20' }
      ]
    },
    'min': {
      name: '规定输入字段的最小值。请与 "max" 属性配合使用，来创建合法值的范围',
      tips: [
        { value: 'number', label: '数字值。规定输入字段允许的最小值' },
        { value: 'date', label: '日期。规定输入字段允许的最小值' }
      ]
    },
    'multiple': {
      name: '如果使用该属性，则允许一个以上的值',
      tips: [{ value: 'multiple', label: '允许一个以上的值' }]
    },
    'name': {
      name: '定义 input 元素的名称',
      tips: [{ value: 'name', label: '元素的名称' }]
    },
    'pattern': {
      name: '规定输入字段的值的模式或格式。例如 pattern="[0-9]" 表示输入值必须是 0 与 9 之间的数字',
      tips: [{ value: 'regexp', label: '规定用于验证输入字段的模式' }]
    },
    'placeholder': {
      name: '规定帮助用户填写输入字段的提示',
      tips: [{ value: 'text', label: '规定用于验证输入字段的模式' }]
    },
    'readonly': {
      name: '规定输入字段为只读',
      tips: [{ value: 'readonly', label: '把输入字段设置为只读' }]
    },
    'required': {
      name: '指示输入字段的值是必需的',
      tips: [{ value: 'required', label: '输入字段的值是必需的' }]
    },
    'size': {
      name: '定义输入字段的宽度',
      tips: [
        { value: 'characters/pixels', label: 'input 元素的宽度' },
        { value: '20px', label: 'input 元素的宽度20px' }
      ]
    },
    'src': {
      name: '定义以提交按钮形式显示的图像的 URL',
      tips: [
        { value: 'URL', label: '作为提交按钮使用的图像的 URL' }
      ]
    },
    'step': {
      name: '规定输入字的的合法数字间隔',
      tips: [
        { value: '0.1', label: '数字增加间隔0.1' },
        { value: '1', label: '数字增加间隔1' },
        { value: 'number', label: '规定输入字段的合法数字间隔' }
      ]
    },
    'type': {
      name: '规定 input 元素的类型',
      tips: [
        { value: 'button', label: '定义可点击按钮（多数情况下，用于通过 JavaScript 启动脚本）' },
        { value: 'checkbox', label: '定义复选框' },
        { value: 'file', label: '定义输入字段和 "浏览"按钮，供文件上传' },
        { value: 'hidden', label: '定义隐藏的输入字段' },
        { value: 'image', label: '定义图像形式的提交按钮' },
        { value: 'password', label: '定义密码字段。该字段中的字符被掩码' },
        { value: 'radio', label: '定义单选按钮' },
        { value: 'reset', label: '定义重置按钮。重置按钮会清除表单中的所有数据' },
        { value: 'submit', label: '定义提交按钮。提交按钮会把表单数据发送到服务器' },
        { value: 'text', label: '定义单行的输入字段，用户可在其中输入文本。默认宽度为 20 个字符' }
      ]
    },
    'value': {
      name: '规定 input 元素的值',
      tips: [
        { value: 'value', label: 'input 元素的值' }
      ]
    },
    'width': {
      name: '定义 input 字段的宽度。（适用于 type="image"）',
      tips: [
        { value: 'pixels', label: '以像素计的宽度。（比如 "100px" 或仅仅是 "100"）' },
        { value: '%', label: '以包含元素的百分比计的宽度（比如 "50%"）' },
        { value: '100px', label: '输入框宽度100px' },
        { value: '50%', label: '输入框宽度50%' }
      ]
    }
  },
  'ins': {
    'cite': {
      name: '指向另外一个文档的 URL，此文档可解释文本被插入的原因',
      tips: [
        { value: 'URL', label: '文档的地址，该文档解释了文本被插入或修改的原因' }
      ]
    },
    'datetime': {
      name: '定义文本被插入的日期和时间',
      tips: [
        { value: 'YYYY-MM-DDThh:mm:ssTZD', label: '文本被插入或修改的日期和时间' }
      ]
    }
  },
  'keygen': {
    'autofocus': {
      name: '使 keygen 字段在页面加载时获得焦点',
      tips: [
        { value: 'autofocus', label: '当页面加载时获得焦点' }
      ]
    },
    'challenge': {
      name: '如果使用，则将 keygen 的值设置为在提交时询问',
      tips: [
        { value: 'challenge', label: '将 keygen 的值设置为在提交时询问' }
      ]
    },
    'disabled': {
      name: '禁用 keytag 字段',
      tips: [
        { value: 'disabled', label: '禁用 keygen 字段' }
      ]
    },
    'form': {
      name: '定义该 keygen 字段所属的一个或多个表单',
      tips: [
        { value: 'id', label: 'keygen 字段所属的一个或多个表单的 id' }
      ]
    },
    'keytype': {
      name: '定义 keytype。rsa 生成 RSA 密钥',
      tips: [
        { value: 'rsa', label: '规定 RSA 安全算法（如支持，则是默认值）' },
        { value: '其他', label: '规定一个安全算法，不同浏览器支持不同' }
      ]
    },
    'name': {
      name: '定义 keygen 元素的唯一名称。name 属性用于在提交表单时搜集字段的值',
      tips: [
        { value: 'name', label: 'keygen 元素的名称' }
      ]
    }
  },
  'label': {
    'for': {
      name: '规定 label 绑定到哪个表单元素',
      tips: [
        { value: 'element_id', label: 'label 要绑定的元素的 id' }
      ]
    },
    'form': {
      name: '规定 label 字段所属的一个或多个表单',
      tips: [
        { value: 'id', label: 'label 所属的一个或多个表单的 id' }
      ]
    }
  },
  'legend': {
    'align': {
      name: '为 fieldset 中的标题定义对齐方式(不推荐)',
      tips: [
        { value: 'left', label: '对标题进行左对齐' },
        { value: 'right', label: '对标题进行右对齐' },
        { value: 'top', label: '对标题进行上对齐' },
        { value: 'bottom', label: '对标题进行下对齐' }
      ]
    }
  },
  'li': {
    'type': {
      name: '规定使用哪种项目符号(不推荐)',
      tips: [
        { value: '1', label: '数字顺序的有序列表（默认值）（1, 2, 3, 4）' },
        { value: 'a', label: '字母顺序的有序列表，小写（a, b, c, d）' },
        { value: 'A', label: '字母顺序的有序列表，大写（a, b, c, d）' },
        { value: 'i', label: '罗马数字，小写（i, ii, iii, iv）' },
        { value: 'I', label: '罗马数字，大写（i, ii, iii, iv）' },
        { value: 'disc', label: '默认值。实心圆' },
        { value: 'circle', label: '空心圆' },
        { value: 'square', label: '实心方块' }
      ]
    },
    'value': {
      name: '规定列表项目的数字(不推荐)',
      tips: [
        { value: 'number', label: '当前列表项目的数字（序号）' }
      ]
    }
  },
  'link': {
    'href': {
      name: '规定被链接文档的位置',
      tips: [
        { value: 'URL', label: '超链接的 URL' }
      ]
    },
    'hreflang': {
      name: '规定被链接文档中文本的语言',
      tips: [
        { value: 'zh', label: '中文(简体)' },
        { value: 'en', label: '英文' },
        { value: 'ja', label: '日语' },
        { value: 'ko', label: '韩语' },
        { value: 'https://www.w3school.com.cn/tags/html_ref_language_codes.asp', label: '语言对照表' }
      ]
    },
    'media': {
      name: '规定被链接文档将被显示在什么设备上',
      tips: [
        { value: 'screen', label: '计算机屏幕（默认）' },
        { value: 'tty', label: '电传打字机以及类似的使用等宽字符网格的媒介' },
        { value: 'tv', label: '电视机类型设备（低分辨率、有限的滚屏能力）' },
        { value: 'projection', label: '放映机' },
        { value: 'handheld', label: '手持设备（小屏幕、有限带宽）' },
        { value: 'print', label: '打印预览模式/打印页面' },
        { value: 'braille', label: '盲人点字法反馈设备' },
        { value: 'aural', label: '语音合成器' },
        { value: 'all', label: '适用于所有设备' }
      ]
    },
    'rel': {
      name: '规定当前文档与被链接文档之间的关系',
      tips: [
        { value: 'alternate', label: '文档的替代版本（比如打印页、翻译或镜像）' },
        { value: 'stylesheet', label: '文档的外部样式表' },
        { value: 'start', label: '集合中的第一个文档' },
        { value: 'next', label: '集合中的下一个文档' },
        { value: 'prev', label: '集合中的上一个文档' },
        { value: 'contents', label: '文档的目录' },
        { value: 'index', label: '文档的索引' },
        { value: 'glossary', label: '在文档中使用的词汇的术语表（解释）' },
        { value: 'copyright', label: '包含版权信息的文档' },
        { value: 'chapter', label: '文档的章' },
        { value: 'section', label: '文档的节' },
        { value: 'subsection', label: '文档的小节' },
        { value: 'appendix', label: '文档的附录' },
        { value: 'help', label: '帮助文档' },
        { value: 'bookmark', label: '相关文档' }
      ]
    },
    'sizes': {
      name: '规定被链接资源的尺寸。仅适用于 rel="icon"',
      tips: [
        { value: 'heightxwidth', label: '为被链接的图标规定一个或多个以像素计的高度/宽度值对。高度与宽度之间由 "x" 或 "X" 分隔' },
        { value: 'any', label: '规定图标是可伸缩的（比如 SVG 图像）' }
      ]
    },
    'type ': {
      name: '规定被链接资源的尺寸。仅适用于 rel="icon"',
      tips: [
        { value: 'text/html', label: '超文本标记语言文本(.html，.htm)' },
        { value: 'text/plain', label: '普通文本(.txt)' },
        { value: 'image/gif', label: 'GIF图形(.gif)' },
        { value: 'image/jpeg', label: 'JPEG图形(.jpeg，.jpg)' },
        { value: 'text/css', label: '层叠样式文本(.css)' },
        { value: 'audio/mpeg', label: '音频文件(.mp3)' },
        { value: 'application/pdf', label: '便携式文档格式(.pdf)' },
        { value: 'application/msword', label: 'Word文档(.doc)' },
        { value: 'application/zip', label: '压缩文件(.zip)' },
        { value: 'application/octet-stream', label: '下载文件类型(.exe)' },
        { value: 'text/javascript', label: 'javascript' }
      ]
    }
  },
  'map': {
    'id': {
      name: '为 map 标签定义唯一的名称',
      tips: [
        { value: 'unique_name', label: '名称' }
      ]
    },
    'name': {
      name: '为 image-map 规定的名称',
      tips: [
        { value: 'name', label: '名称' }
      ]
    }
  },
  'menu': {
    'label': {
      name: '规定菜单的可见标签',
      tips: [
        { value: 'text', label: '为菜单规定可见的标签' }
      ]
    },
    'type': {
      name: '规定要显示哪种菜单类型',
      tips: [
        { value: 'list', label: '默认。规定列表菜单。一个用户可执行或激活的命令列表（li 元素）' },
        { value: 'context', label: '规定上下文菜单。该菜单必须在用户能够与命令进行交互之前被激活' },
        { value: 'toolbar', label: '规定工具栏菜单。活动式命令，允许用户立即与命令进行交互' }
      ]
    }
  },
  'meter': {
    'form': {
      name: '规定 meter 元素所属的一个或多个表单',
      tips: [
        { value: 'form_id', label: '规定 meter 元素所属的表单元素。该属性的值必须是同一文档中 form 元素的 id 属性值' }
      ]
    },
    'high': {
      name: '规定被视作高的值的范围',
      tips: [
        { value: '10', label: '' },
        { value: 'number', label: '规定被视作高值的浮点数' }
      ]
    },
    'low': {
      name: '规定被视作低的值的范围',
      tips: [
        { value: '10', label: '' },
        { value: 'number', label: '规定被视作低值的浮点数' }
      ]
    },
    'max': {
      name: '规定范围的最大值',
      tips: [
        { value: '1', label: '' },
        { value: 'number', label: '规定度量的最大值，浮点值。默认值是 "1"' }
      ]
    },
    'min': {
      name: '规定范围的最小值',
      tips: [
        { value: '0', label: '' },
        { value: 'number', label: '规定度量的最小值，浮点值。默认值是 "0"' }
      ]
    },
    'optimum': {
      name: '规定度量的优化值',
      tips: [
        { value: '0.5', label: '最佳值为 0.5 的测量范围' },
        { value: 'number', label: '规定测量范围的最佳值，浮点数' }
      ]
    },
    'value': {
      name: '必需。规定度量的当前值',
      tips: [
        { value: 'number', label: '必需。规定测量范围的当前值，浮点数' }
      ]
    }
  },
  'object': {
    'align': {
      name: '定义围绕该对象的文本对齐方式',
      tips: [
        { value: 'left', label: '左对齐' },
        { value: 'right', label: '右对齐' },
        { value: 'top', label: '上对齐' },
        { value: 'bottom', label: '下对齐' }
      ]
    },
    'archive': {
      name: '由空格分隔的指向档案文件的 URL 列表。这些档案文件包含了与对象相关的资源',
      tips: [
        { value: 'URL', label: '路径' }
      ]
    },
    'border': {
      name: '定义对象周围的边框',
      tips: [
        { value: '1px', label: '边框1px' },
        { value: 'pixels', label: '自定义数值' }
      ]
    },
    'classid': {
      name: '定义嵌入 Windows Registry 中或某个 URL 中的类的 ID 值，此属性可用来指定浏览器中包含的对象的位置，通常是一个 Java 类',
      tips: [
        { value: 'class ID', label: '对象的绝对或相对的 URL' }
      ]
    },
    'codebase': {
      name: '定义在何处可找到对象所需的代码，提供一个基准 URL',
      tips: [
        { value: 'URL', label: '路径' }
      ]
    },
    'codetype': {
      name: '通过 classid 属性所引用的代码的 MIME 类型',
      tips: [
        { value: 'text/html', label: '超文本标记语言文本(.html，.htm)' },
        { value: 'text/plain', label: '普通文本(.txt)' },
        { value: 'image/gif', label: 'GIF图形(.gif)' },
        { value: 'image/jpeg', label: 'JPEG图形(.jpeg，.jpg)' },
        { value: 'text/css', label: '层叠样式文本(.css)' },
        { value: 'audio/mpeg', label: '音频文件(.mp3)' },
        { value: 'application/pdf', label: '便携式文档格式(.pdf)' },
        { value: 'application/msword', label: 'Word文档(.doc)' },
        { value: 'application/zip', label: '压缩文件(.zip)' },
        { value: 'application/octet-stream', label: '下载文件类型(.exe)' },
        { value: 'text/javascript', label: 'javascript' }
      ]
    },
    'data': {
      name: '定义引用对象数据的 URL。如果有需要对象处理的数据文件,要用 data 属性来指定这些数据文件',
      tips: [
        { value: 'URL', label: '路径' }
      ]
    },
    'height': {
      name: '定义对象的高度',
      tips: [
        { value: '100px', label: '高度100px' },
        { value: 'pixels', label: '自定义数值' }
      ]
    },
    'hspace': {
      name: '定义对象周围水平方向的空白',
      tips: [
        { value: '10px', label: '水平方向空白10px' },
        { value: 'pixels', label: '自定义数值' }
      ]
    },
    'name': {
      name: '为对象定义唯一的名称（以便在脚本中使用）',
      tips: [
        { value: 'unique_name', label: '自定义名称' }
      ]
    },
    'standby': {
      name: '定义当对象正在加载时所显示的文本',
      tips: [
        { value: 'text', label: '自定义文本' }
      ]
    },
    'type': {
      name: '定义被规定在 data 属性中指定的文件中出现的数据的 MIME 类型',
      tips: [
        { value: 'text/html', label: '超文本标记语言文本(.html，.htm)' },
        { value: 'text/plain', label: '普通文本(.txt)' },
        { value: 'image/gif', label: 'GIF图形(.gif)' },
        { value: 'image/jpeg', label: 'JPEG图形(.jpeg，.jpg)' },
        { value: 'text/css', label: '层叠样式文本(.css)' },
        { value: 'audio/mpeg', label: '音频文件(.mp3)' },
        { value: 'application/pdf', label: '便携式文档格式(.pdf)' },
        { value: 'application/msword', label: 'Word文档(.doc)' },
        { value: 'application/zip', label: '压缩文件(.zip)' },
        { value: 'application/octet-stream', label: '下载文件类型(.exe)' },
        { value: 'text/javascript', label: 'javascript' }
      ]
    },
    'usemap': {
      name: '规定与对象一同使用的客户端图像映射的 URL',
      tips: [
        { value: 'URL', label: '路径' }
      ]
    },
    'vspace': {
      name: '定义对象的垂直方向的空白',
      tips: [
        { value: '10px', label: '垂直方向空白10px' },
        { value: 'pixels', label: '自定义数值' }
      ]
    },
    'width': {
      name: '定义对象的宽度',
      tips: [
        { value: '100px', label: '宽度100px' },
        { value: 'pixels', label: '自定义数值' }
      ]
    }
  },
  'ol': {
    'compact': {
      name: '规定列表呈现的效果比正常情况更小巧(不推荐)',
      tips: [
        { value: 'compact', label: '规定列表呈现更紧凑小巧的效果' }
      ]
    },
    'reversed': {
      name: '规定列表顺序为降序。(9,8,7...)',
      tips: [
        { value: 'reversed', label: '降序排列' }
      ]
    },
    'start': {
      name: '规定有序列表的起始值',
      tips: [
        { value: '1', label: '从数字1起始' },
        { value: '10', label: '从数字10起始' },
        { value: 'number', label: '数字。有序列表的开始点' }
      ]
    },
    'type': {
      name: '规定在列表中使用的标记类型',
      tips: [
        { value: '1', label: '默认值。数字有序列表。（1、2、3、4）' },
        { value: 'a', label: '按字母顺序排列的有序列表，小写。（a、b、c、d）' },
        { value: 'A', label: '按字母顺序排列的有序列表，大写。（A、B、C、D）' },
        { value: 'i', label: '罗马字母，小写。（i, ii, iii, iv）' },
        { value: 'I', label: '罗马字母，大写。（I, II, III, IV）' }
      ]
    }
  },
  'optgroup': {
    'label': {
      name: '为选项组规定描述',
      tips: [
        { value: 'text', label: '有关被包含选项的描述内容' }
      ]
    },
    'disabled': {
      name: '规定禁用该选项组',
      tips: [
        { value: 'disabled', label: '禁用选项组' }
      ]
    }
  },
  'option': {
    'disabled': {
      name: '规定此选项应在首次加载时被禁用',
      tips: [
        { value: 'disabled', label: '规定应该禁用选项' }
      ]
    },
    'label': {
      name: '定义当使用 optgroup 时所使用的标注',
      tips: [
        { value: 'text', label: '选项的更短的版本' }
      ]
    },
    'selected': {
      name: '规定选项（在首次显示在列表中时）表现为选中状态',
      tips: [
        { value: 'selected', label: '预先选择一个选项' }
      ]
    },
    'value': {
      name: '定义送往服务器的选项值',
      tips: [
        { value: 'value', label: '发送到服务器的值' }
      ]
    }
  },
  'output': {
    'for': {
      name: '定义输出域相关的一个或多个元素',
      tips: [
        { value: 'element_id', label: '一个或多个元素的 id 列表，以空格分隔，规定计算中使用的元素与计算结果之间的关系' }
      ]
    },
    'form': {
      name: '定义输入字段所属的一个或多个表单',
      tips: [
        { value: 'form_id', label: '规定 output 元素所属的表单元素。该值必须是同一文档中的 form 元素的 id 属性' }
      ]
    },
    'name': {
      name: '定义对象的唯一名称。（表单提交时使用）',
      tips: [
        { value: 'name', label: '规定 output 元素的名称' }
      ]
    }
  },
  'p': {
    'id': {
      name: '规定元素的唯一 id',
      tips: [
        { value: 'id', label: '规定元素的唯一 id' }
      ]
    },
    'align': {
      name: '规定 div 元素中的内容的对齐方式(不推荐)',
      tips: [
        { value: 'left', label: '左对齐内容' },
        { value: 'right', label: '右对齐内容' },
        { value: 'center', label: '居中对齐内容' },
        { value: 'justify', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' }
      ]
    },
    'accesskey': {
      name: '规定激活元素的快捷键',
      tips: [
        { value: 'character', label: '规定激活（使元素获得焦点）元素的便捷按键' }
      ]
    },
    'contenteditable': {
      name: '规定元素内容是否可编辑',
      tips: [
        { value: 'true', label: '规定元素可编辑' },
        { value: 'false', label: '规定元素不可编辑' }
      ]
    },
    'dir': {
      name: '规定元素中内容的文本方向',
      tips: [
        { value: 'ltr', label: '默认。从左向右的文本方向' },
        { value: 'rtl', label: '从右向左的文本方向' }
      ]
    },
    'draggable': {
      name: '规定元素是否可拖动',
      tips: [
        { value: 'true', label: '规定元素的可拖动的' },
        { value: 'false', label: '规定元素不可拖动' },
        { value: 'auto', label: '使用浏览器的默认行为' }
      ]
    },
    'hidden': {
      name: '规定元素是否隐藏',
      tips: [
        { value: 'hidden', label: '规定元素被隐藏' }
      ]
    },
    'lang': {
      name: '规定元素是否隐藏',
      tips: [
        { value: 'zh', label: '中文(简体)' },
        { value: 'en', label: '英文' },
        { value: 'ja', label: '日语' },
        { value: 'ko', label: '韩语' },
        { value: 'https://www.w3school.com.cn/tags/html_ref_language_codes.asp', label: '语言对照表' }
      ]
    },
    'tabindex': {
      name: '规定元素的 tab 键次序',
      tips: [
        { value: '1', label: '第一次按tab切换到' },
        { value: '2', label: '第二次按tab切换到' },
        { value: 'number', label: '规定元素的 tab 键控制次序（1 是第一个）' }
      ]
    },
    'title': {
      name: '规定有关元素的额外信息',
      tips: [
        { value: 'title', label: '元素的额外信息' }
      ]
    },
    'translate': {
      name: '规定是否应该翻译元素内容',
      tips: [
        { value: 'yes', label: '规定应该翻译元素内容' },
        { value: 'no', label: '规定不应翻译元素内容' }
      ]
    }
  },
  'progress': {
    'max': {
      name: '规定任务一共需要多少工作',
      tips: [
        { value: '100', label: '进度条完成点数值100' },
        { value: 'number', label: '浮点数值，规定任务总共需要多少工作' }
      ]
    },
    'value': {
      name: '规定已经完成多少任务',
      tips: [
        { value: '0', label: '进度条当前完成数值0' },
        { value: 'number', label: '浮点数值，规定已完成多少任务' }
      ]
    }
  },
  'q': {
    'cite': {
      name: '定义引用的出处或来源（citation）',
      tips: [
        { value: 'URL', label: '引用的来源的 URL' }
      ]
    }
  },
  'script': {
    'type': {
      name: '指示脚本的 MIME 类型',
      tips: [
        { value: 'text/html', label: '超文本标记语言文本(.html，.htm)' },
        { value: 'text/css', label: 'css层叠样式' },
        { value: 'application/json', label: 'json数据' },
        { value: 'text/javascript', label: 'javascript' },
        { value: 'application/javascript', label: 'javascript' }
      ]
    },
    'async': {
      name: '规定异步执行脚本（仅适用于外部脚本）',
      tips: [
        { value: 'https://xxx.js', label: '外部脚本url' },
        { value: 'async', label: '规定脚本将被异步执行' }
      ]
    },
    'charset': {
      name: '规定在外部脚本文件中使用的字符编码',
      tips: [
        { value: 'UTF-8', label: 'Unicode字符编码' },
        { value: 'ISO-8859-1', label: '拉丁字母表的编码' },
        { value: 'GB2312', label: '简体汉字编码' },
        { value: 'BIG5', label: '繁体汉字编码' }
      ]
    },
    'defer': {
      name: '规定是否对脚本执行进行延迟，直到页面加载为止',
      tips: [
        { value: 'defer', label: '延迟脚本的执行' }
      ]
    },
    'language': {
      name: '规定脚本语言(不推荐，使用type替代)',
      tips: [
        { value: 'text/html', label: '超文本标记语言文本(.html，.htm)' },
        { value: 'text/css', label: 'css层叠样式' },
        { value: 'application/json', label: 'json数据' },
        { value: 'text/javascript', label: 'javascript' },
        { value: 'application/javascript', label: 'javascript' }
      ]
    },
    'src': {
      name: '规定外部脚本文件的 URL',
      tips: [
        { value: 'URL', label: '外部脚本的 URL' }
      ]
    }
  },
  'select': {
    'autofocus': {
      name: '规定在页面加载后文本区域自动获得焦点',
      tips: [
        { value: 'autofocus ', label: '自动获得焦点' }
      ]
    },
    'disabled': {
      name: '规定禁用该下拉列表',
      tips: [
        { value: 'disabled', label: '规定应该禁用该下拉列表' }
      ]
    },
    'form': {
      name: '规定文本区域所属的一个或多个表单',
      tips: [
        { value: 'form_id', label: '规定 select 元素所属的 form 元素。该属性的值必须是同一文档中的某个 form 元素的 id 属性' }
      ]
    },
    'multiple': {
      name: '规定可选择多个选项',
      tips: [
        { value: 'multiple', label: '规定可同时选择多个选项' }
      ]
    },
    'name': {
      name: '规定下拉列表的名称',
      tips: [
        { value: 'name', label: '下拉列表的名称' }
      ]
    },
    'required': {
      name: '规定文本区域是必填的',
      tips: [
        { value: 'required', label: '文本区域是必填的' }
      ]
    },
    'size': {
      name: '规定下拉列表中可见选项的数目',
      tips: [
        { value: '3', label: '下拉列表中3条可见' },
        { value: '5', label: '下拉列表中5条可见' },
        { value: 'number', label: '下拉列表中可见选项的数目' }
      ]
    }
  },
  'source': {
    'src': {
      name: '规定媒体文件的 URL',
      tips: [
        { value: 'URL ', label: '规定媒体文件的 URL' }
      ]
    },
    'type': {
      name: '规定媒体资源的 MIME 类型',
      tips: [
        { value: 'image/gif', label: 'GIF图形(.gif)' },
        { value: 'image/jpeg', label: 'JPEG图形(.jpeg，.jpg)' },
        { value: 'audio/ogg', label: '音频文件(.oga,.ogg,.ogv)' },
        { value: 'audio/mp4', label: '音频文件(.m4a,.m4b,.m4r)' },
        { value: 'audio/mpeg', label: '音频文件(.mp3)' },
        { value: 'audio/flac', label: '无损音频文件(.flac)' },
        { value: 'video/3gpp', label: '视频文件(.3gp)' },
        { value: 'video/x-f4v', label: '流媒体视频文件(.f4v)' },
        { value: 'video/x-flv', label: '流媒体视频文件(.flv)' },
        { value: 'video/x-msvideo', label: '视频文件(.avi)' },
        { value: 'video/mp4', label: '视频文件(.mp4)' },
        { value: 'video/x-matroska', label: '视频文件(.mkv)' },
        { value: 'application/pdf', label: '便携式文档格式(.pdf)' },
        { value: 'application/msword', label: 'Word文档(.doc)' },
        { value: 'text/csv', label: '文档(.csv)' },
        { value: 'application/zip', label: '压缩文件(.zip)' }
      ]
    }
  },
  'span': {
    'id': {
      name: '规定元素的唯一 id',
      tips: [
        { value: 'id', label: '规定元素的唯一 id' }
      ]
    },
    'accesskey': {
      name: '规定激活元素的快捷键',
      tips: [
        { value: 'character', label: '规定激活（使元素获得焦点）元素的便捷按键' }
      ]
    },
    'contenteditable': {
      name: '规定元素内容是否可编辑',
      tips: [
        { value: 'true', label: '规定元素可编辑' },
        { value: 'false', label: '规定元素不可编辑' }
      ]
    },
    'dir': {
      name: '规定元素中内容的文本方向',
      tips: [
        { value: 'ltr', label: '默认。从左向右的文本方向' },
        { value: 'rtl', label: '从右向左的文本方向' }
      ]
    },
    'draggable': {
      name: '规定元素是否可拖动',
      tips: [
        { value: 'true', label: '规定元素的可拖动的' },
        { value: 'false', label: '规定元素不可拖动' },
        { value: 'auto', label: '使用浏览器的默认行为' }
      ]
    },
    'hidden': {
      name: '规定元素是否隐藏',
      tips: [
        { value: 'hidden', label: '规定元素被隐藏' }
      ]
    },
    'lang': {
      name: '规定元素是否隐藏',
      tips: [
        { value: 'zh', label: '中文(简体)' },
        { value: 'en', label: '英文' },
        { value: 'ja', label: '日语' },
        { value: 'ko', label: '韩语' },
        { value: 'https://www.w3school.com.cn/tags/html_ref_language_codes.asp', label: '语言对照表' }
      ]
    },
    'tabindex': {
      name: '规定元素的 tab 键次序',
      tips: [
        { value: '1', label: '第一次按tab切换到' },
        { value: '2', label: '第二次按tab切换到' },
        { value: 'number', label: '规定元素的 tab 键控制次序（1 是第一个）' }
      ]
    },
    'title': {
      name: '规定有关元素的额外信息',
      tips: [
        { value: 'title', label: '元素的额外信息' }
      ]
    },
    'translate': {
      name: '规定是否应该翻译元素内容',
      tips: [
        { value: 'yes', label: '规定应该翻译元素内容' },
        { value: 'no', label: '规定不应翻译元素内容' }
      ]
    }
  },
  'style': {
    'type': {
      name: '规定样式表的 MIME 类型',
      tips: [
        { value: 'text/css ', label: '样式表的 MIME 类型text/css' },
        { value: 'MIME_type ', label: '样式表的 MIME 类型。目前，唯一可能的值是 "text/css"' }
      ]
    },
    'media': {
      name: '为样式表规定不同的媒介类型',
      tips: [
        { value: 'screen', label: '计算机屏幕（默认值）' },
        { value: 'tty', label: '电传打字机以及使用等宽字符网格的类似媒介' },
        { value: 'tv', label: '电视类型设备（低分辨率、有限的屏幕翻滚能力）' },
        { value: 'projection', label: '放映机' },
        { value: 'handheld', label: '手持设备（小屏幕、有限的带宽）' },
        { value: 'print', label: '打印预览模式 / 打印页' },
        { value: 'braille', label: '盲人用点字法反馈设备' },
        { value: 'aural', label: '语音合成器' },
        { value: 'all', label: '适合所有设备' }
      ]
    }
  },
  'table': {
    'align': {
      name: '规定表格相对周围元素的对齐方式(不推荐)',
      tips: [
        { value: 'left ', label: '左对齐表格' },
        { value: 'right ', label: '右对齐表格' },
        { value: 'center ', label: '居中对齐表格' }
      ]
    },
    'bgcolor': {
      name: '规定表格的背景颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的背景颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的背景颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的背景颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'border': {
      name: '规定表格边框的宽度',
      tips: [
        { value: '1px', label: '边框宽度1px' },
        { value: 'pixels', label: '规定表格边框宽度' }
      ]
    },
    'cellpadding': {
      name: '规定单元边沿与其内容之间的空白',
      tips: [
        { value: '5px', label: '单元边沿与内容之间的空白5px' },
        { value: 'pixels', label: '规定单元边沿与其内容之间的空白' }
      ]
    },
    'cellspacing': {
      name: '规定单元格之间的空白',
      tips: [
        { value: '5px', label: '单元之间的空间5px' },
        { value: 'pixels', label: '规定单元之间的空间' }
      ]
    },
    'frame': {
      name: '规定外侧边框的哪个部分是可见的',
      tips: [
        { value: 'void', label: '不显示外侧边框' },
        { value: 'above', label: '显示上部的外侧边框' },
        { value: 'below', label: '显示下部的外侧边框' },
        { value: 'hsides', label: '显示上部和下部的外侧边框' },
        { value: 'vsides', label: '显示左边和右边的外侧边框' },
        { value: 'lhs', label: '显示左边的外侧边框' },
        { value: 'rhs', label: '显示右边的外侧边框' },
        { value: 'box', label: '在所有四个边上显示外侧边框' },
        { value: 'border', label: '在所有四个边上显示外侧边框' }
      ]
    },
    'rules': {
      name: '规定内侧边框的哪个部分是可见的',
      tips: [
        { value: 'none', label: '没有线条' },
        { value: 'groups', label: '位于行组和列组之间的线条' },
        { value: 'rows', label: '位于行之间的线条' },
        { value: 'cols', label: '位于列之间的线条' },
        { value: 'all', label: '位于行和列之间的线条' }
      ]
    },
    'summary': {
      name: '规定表格的摘要',
      tips: [
        { value: 'text', label: '表格内容的摘要' }
      ]
    },
    'width': {
      name: '规定表格的宽度',
      tips: [
        { value: 'pixels', label: '设置以像素计的宽度（例子：width="50"）' },
        { value: '%', label: '设置以包含元素的百分比计的宽度（例子：width="50%"）' },
        { value: '200px', label: '表格宽度200px' },
        { value: '1000%', label: '表格宽度100%' }
      ]
    }
  },
  'tbody': {
    'align': {
      name: '定义 tbody 元素中内容的对齐方式',
      tips: [
        { value: 'left ', label: '左对齐内容（默认值' },
        { value: 'right ', label: '右对齐内容' },
        { value: 'center ', label: '居中对齐内容（th 元素的默认值）' },
        { value: 'center ', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' },
        { value: 'char ', label: '将内容对准指定字符' }
      ]
    },
    'char': {
      name: '规定根据哪个字符来进行文本对齐，仅当 align 属性设置为 "char" 时，才能使用 char 属性',
      tips: [
        { value: 'character', label: '规定将内容与之对齐的字符' }
      ]
    },
    'charoff': {
      name: '规定第一个对齐字符的偏移量，设置 char 属性时，才能使用 charoff 属性',
      tips: [
        { value: 'number', label: '规定对齐方式。正数规定向字符的右边对齐。负数规定向字符的左边对齐' }
      ]
    },
    'valign': {
      name: '规定 tbody 元素中内容的垂直对齐方式',
      tips: [
        { value: 'top', label: '对内容进行上对齐' },
        { value: 'middle', label: '对内容进行居中对齐（默认值）' },
        { value: 'bottom', label: '对内容进行下对齐' },
        { value: 'baseline', label: '与基线对齐' }
      ]
    }
  },
  'td': {
    'abbr': {
      name: '规定单元格中内容的缩写版本',
      tips: [
        { value: 'text', label: '单元格的短描述' }
      ]
    },
    'align': {
      name: '规定根据哪个字符来进行文本对齐',
      tips: [
        { value: 'left ', label: '左对齐内容（默认值)' },
        { value: 'right ', label: '右对齐内容' },
        { value: 'center ', label: '居中对齐内容（th 元素的默认值）' },
        { value: 'center ', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' },
        { value: 'char ', label: '将内容对准指定字符' }
      ]
    },
    'axis': {
      name: '对单元进行分类',
      tips: [
        { value: 'category_name', label: '规定类别的名称' }
      ]
    },
    'bgcolor': {
      name: '规定单元格的背景颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的背景颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的背景颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的背景颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'char': {
      name: '规定根据哪个字符来进行内容的对齐，仅当 align 属性设置为 "char" 时，才能使用 char 属性',
      tips: [
        { value: 'character', label: '规定将内容与之对齐的字符' }
      ]
    },
    'charoff': {
      name: '规定对齐字符的偏移量，设置 char 属性时，才能使用 charoff 属性',
      tips: [
        { value: 'number', label: '规定对齐方式。正数规定向字符的右边对齐。负数规定向字符的左边对齐。' }
      ]
    },
    'colspan': {
      name: '规定单元格可横跨的列数',
      tips: [
        { value: '2', label: '当前单元格横跨2列' },
        { value: '3', label: '当前单元格横跨3列' },
        { value: 'number', label: '设置单元格可横跨的列数' }
      ]
    },
    'headers': {
      name: '规定与单元格相关的表头',
      tips: [
        { value: 'idrefs', label: '规定与表格单元相关联的一个或多个表头单元的 id' }
      ]
    },
    'height': {
      name: '规定表格单元格的高度(不推荐)',
      tips: [
        { value: 'pixels', label: '以像素计的高度值（比如 "100px"）' },
        { value: 'percent', label: '以包含元素百分比计的高度值（比如 "20%"）' },
        { value: '20px', label: '单元格高20px' },
        { value: '10%', label: '单元格高10%' }
      ]
    },
    'nowrap': {
      name: '规定单元格中的内容是否折行(不推荐)',
      tips: [
        { value: 'nowrap', label: '规定表格单元格中的内容不换行' }
      ]
    },
    'rowspan': {
      name: '规定单元格可横跨的行数',
      tips: [
        { value: '2', label: '当前单元格横跨2行' },
        { value: '3', label: '当前单元格横跨3行' },
        { value: 'number', label: '设置单元格可横跨的行数' }
      ]
    },
    'scope': {
      name: '定义将表头数据与单元数据相关联的方法',
      tips: [
        { value: 'col', label: '规定单元格是列的表头' },
        { value: 'row', label: '规定单元格是行的表头' },
        { value: 'colgroup', label: '规定单元格是列组的表头' },
        { value: 'rowgroup', label: '规定单元格是行组的表头' }
      ]
    },
    'valign': {
      name: '规定单元格内容的垂直排列方式',
      tips: [
        { value: 'top', label: '对内容进行上对齐' },
        { value: 'middle', label: '对内容进行居中对齐（默认值）' },
        { value: 'bottom', label: '对内容进行下对齐' },
        { value: 'baseline', label: '与基线对齐' }
      ]
    },
    'width': {
      name: '规定表格单元格的宽度(不推荐)',
      tips: [
        { value: 'pixels', label: '以像素计的宽度值（比如 "100px"）' },
        { value: 'percent', label: '以包含元素百分比计的宽度值（比如 "20%"）' },
        { value: '20px', label: '单元格宽度20px' },
        { value: '10%', label: '单元格宽度10%' }
      ]
    }
  },
  'textarea': {
    'autofocus': {
      name: '规定在页面加载后文本区域自动获得焦点',
      tips: [
        { value: 'autofocus', label: '自动获得焦点' }
      ]
    },
    'cols': {
      name: '规定文本区内的可见宽度',
      tips: [
        { value: '200 ', label: '可见宽度200' },
        { value: 'number ', label: '规定文本区的宽度（以平均字符数计）' }
      ]
    },
    'disabled': {
      name: '规定禁用该文本区',
      tips: [
        { value: 'disabled', label: '规定应该禁用该文本区' }
      ]
    },
    'form': {
      name: '规定文本区域所属的一个或多个表单',
      tips: [
        { value: 'form_id', label: '规定 textarea 元素所属的 form 元素。该属性的值必须是同一文档中的某个 form 元素的 id 属性' }
      ]
    },
    'maxlength': {
      name: '规定文本区域的最大字符数',
      tips: [
        { value: '200', label: '允许的最大字符数200' },
        { value: 'number', label: '文本区域中允许的最大字符数' }
      ]
    },
    'name': {
      name: '规定文本区的名称',
      tips: [
        { value: 'name_of_textarea', label: '规定文本区的名称' }
      ]
    },
    'placeholder': {
      name: '规定描述文本区域预期值的简短提示',
      tips: [
        { value: '请输入...', label: '规定描述文本区域预期值的简短提示' }
      ]
    },
    'readonly': {
      name: '规定文本区为只读',
      tips: [
        { value: 'readonly', label: '规定文本区为只读' }
      ]
    },
    'required': {
      name: '规定文本区域是必填的',
      tips: [
        { value: 'required', label: '文本区域是必填的' }
      ]
    },
    'rows': {
      name: '规定文本区内的可见行数',
      tips: [
        { value: '3', label: '文本区可见3行' },
        { value: '5', label: '文本区可见5行' },
        { value: 'number', label: '规定文本区的高度（以行数计）' }
      ]
    },
    'wrap': {
      name: '规定当在表单中提交时，文本区域中的文本如何换行',
      tips: [
        { value: 'soft', label: '当在表单中提交时，textarea 中的文本不换行。默认值' },
        { value: 'hard', label: '当在表单中提交时，textarea 中的文本换行（包含换行符）。当使用 "hard" 时，必须规定 cols 属性' }
      ]
    }
  },
  'tfoot': {
    'align': {
      name: '定义 tfoot 元素中内容的对齐方式',
      tips: [
        { value: 'left', label: '左对齐内容（默认值）' },
        { value: 'right', label: '右对齐内容' },
        { value: 'center', label: '居中对齐内容（th 元素的默认值）' },
        { value: 'justify', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' },
        { value: 'char', label: '将内容对准指定字符' }
      ]
    },
    'char': {
      name: '规定根据哪个字符来进行文本对齐，仅当 align 属性设置为 "char" 时，才能使用 char 属性',
      tips: [
        { value: 'character ', label: '规定将内容与之对齐的字符' }
      ]
    },
    'charoff': {
      name: '规定第一个对齐字符的偏移量，设置 char 属性时，才能使用 charoff 属性',
      tips: [
        { value: 'number', label: '规定对齐方式。正数规定向字符的右边对齐。负数规定向字符的左边对齐' }
      ]
    },
    'valign': {
      name: '规定 tfoot 元素中内容的垂直对齐方式',
      tips: [
        { value: 'top', label: '对内容进行上对齐' },
        { value: 'middle', label: '对内容进行居中对齐（默认值）' },
        { value: 'bottom', label: '对内容进行下对齐' },
        { value: 'baseline', label: '与基线对齐' }
      ]
    }
  },
  'th': {
    'abbr': {
      name: '规定单元格中内容的缩写版本',
      tips: [
        { value: 'text', label: '单元格的短描述' }
      ]
    },
    'align': {
      name: '规定根据哪个字符来进行文本对齐',
      tips: [
        { value: 'left ', label: '左对齐内容（默认值)' },
        { value: 'right ', label: '右对齐内容' },
        { value: 'center ', label: '居中对齐内容（th 元素的默认值）' },
        { value: 'center ', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' },
        { value: 'char ', label: '将内容对准指定字符' }
      ]
    },
    'axis': {
      name: '对单元进行分类',
      tips: [
        { value: 'category_name', label: '规定类别的名称' }
      ]
    },
    'bgcolor': {
      name: '规定单元格的背景颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的背景颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的背景颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的背景颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'char': {
      name: '规定根据哪个字符来进行内容的对齐，仅当 align 属性设置为 "char" 时，才能使用 char 属性',
      tips: [
        { value: 'character', label: '规定将内容与之对齐的字符' }
      ]
    },
    'charoff': {
      name: '规定对齐字符的偏移量，设置 char 属性时，才能使用 charoff 属性',
      tips: [
        { value: 'number', label: '规定对齐方式。正数规定向字符的右边对齐。负数规定向字符的左边对齐。' }
      ]
    },
    'colspan': {
      name: '规定单元格可横跨的列数',
      tips: [
        { value: '2', label: '当前单元格横跨2列' },
        { value: '3', label: '当前单元格横跨3列' },
        { value: 'number', label: '设置单元格可横跨的列数' }
      ]
    },
    'headers': {
      name: '规定与单元格相关的表头',
      tips: [
        { value: 'idrefs', label: '规定与表格单元相关联的一个或多个表头单元的 id' }
      ]
    },
    'height': {
      name: '规定表格单元格的高度(不推荐)',
      tips: [
        { value: 'pixels', label: '以像素计的高度值（比如 "100px"）' },
        { value: 'percent', label: '以包含元素百分比计的高度值（比如 "20%"）' },
        { value: '20px', label: '单元格高20px' },
        { value: '10%', label: '单元格高10%' }
      ]
    },
    'nowrap': {
      name: '规定单元格中的内容是否折行(不推荐)',
      tips: [
        { value: 'nowrap', label: '规定表格单元格中的内容不换行' }
      ]
    },
    'rowspan': {
      name: '规定单元格可横跨的行数',
      tips: [
        { value: '2', label: '当前单元格横跨2行' },
        { value: '3', label: '当前单元格横跨3行' },
        { value: 'number', label: '设置单元格可横跨的行数' }
      ]
    },
    'scope': {
      name: '定义将表头数据与单元数据相关联的方法',
      tips: [
        { value: 'col', label: '规定单元格是列的表头' },
        { value: 'row', label: '规定单元格是行的表头' },
        { value: 'colgroup', label: '规定单元格是列组的表头' },
        { value: 'rowgroup', label: '规定单元格是行组的表头' }
      ]
    },
    'valign': {
      name: '规定单元格内容的垂直排列方式',
      tips: [
        { value: 'top', label: '对内容进行上对齐' },
        { value: 'middle', label: '对内容进行居中对齐（默认值）' },
        { value: 'bottom', label: '对内容进行下对齐' },
        { value: 'baseline', label: '与基线对齐' }
      ]
    },
    'width': {
      name: '规定表格单元格的宽度(不推荐)',
      tips: [
        { value: 'pixels', label: '以像素计的宽度值（比如 "100px"）' },
        { value: 'percent', label: '以包含元素百分比计的宽度值（比如 "20%"）' },
        { value: '20px', label: '单元格宽度20px' },
        { value: '10%', label: '单元格宽度10%' }
      ]
    }
  },
  'thead': {
    'align': {
      name: '定义 tfoot 元素中内容的对齐方式',
      tips: [
        { value: 'left', label: '左对齐内容（默认值）' },
        { value: 'right', label: '右对齐内容' },
        { value: 'center', label: '居中对齐内容（th 元素的默认值）' },
        { value: 'justify', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' },
        { value: 'char', label: '将内容对准指定字符' }
      ]
    },
    'char': {
      name: '规定根据哪个字符来进行文本对齐，仅当 align 属性设置为 "char" 时，才能使用 char 属性',
      tips: [
        { value: 'character ', label: '规定将内容与之对齐的字符' }
      ]
    },
    'charoff': {
      name: '规定第一个对齐字符的偏移量，设置 char 属性时，才能使用 charoff 属性',
      tips: [
        { value: 'number', label: '规定对齐方式。正数规定向字符的右边对齐。负数规定向字符的左边对齐' }
      ]
    },
    'valign': {
      name: '规定 tfoot 元素中内容的垂直对齐方式',
      tips: [
        { value: 'top', label: '对内容进行上对齐' },
        { value: 'middle', label: '对内容进行居中对齐（默认值）' },
        { value: 'bottom', label: '对内容进行下对齐' },
        { value: 'baseline', label: '与基线对齐' }
      ]
    }
  },
  'time': {
    'datetime': {
      name: '规定日期 / 时间。否则，由元素的内容给定日期 / 时间',
      tips: [
        { value: 'YYYY-MM-DDThh:mm:ssTZD', label: '日期或时间' }
      ]
    },
    'pubdate': {
      name: '指示 time 元素中的日期 / 时间是文档（或 article 元素）的发布日期',
      tips: [
        { value: 'pubdate ', label: '指示 time 元素中的日期 / 时间是文档（或最近的前辈 article 元素）的发布日期' }
      ]
    }
  },
  'title': {
    'dir': {
      name: '规定元素中内容的文本方向',
      tips: [
        { value: 'ltr', label: '文本从左向右正常方向' },
        { value: 'rtl', label: '文本从右向左' }
      ]
    },
    'lang': {
      name: '规定元素中内容的语言代码',
      tips: [
        { value: 'zh', label: '中文(简体)' },
        { value: 'en', label: '英文' },
        { value: 'ja', label: '日语' },
        { value: 'ko', label: '韩语' },
        { value: 'https://www.w3school.com.cn/tags/html_ref_language_codes.asp', label: '语言对照表' }
      ]
    }
  },
  'tr': {
    'align': {
      name: '定义 tfoot 元素中内容的对齐方式',
      tips: [
        { value: 'left', label: '左对齐内容（默认值）' },
        { value: 'right', label: '右对齐内容' },
        { value: 'center', label: '居中对齐内容（th 元素的默认值）' },
        { value: 'justify', label: '对行进行伸展，这样每行都可以有相等的长度（就像在报纸和杂志中）' },
        { value: 'char', label: '将内容对准指定字符' }
      ]
    },
    'bgcolor': {
      name: '规定单元格的背景颜色(不推荐)',
      tips: [
        { value: 'color_name', label: '规定颜色值为颜色名称的背景颜色（比如 "red"）' },
        { value: 'hex_number', label: '规定颜色值为十六进制值的背景颜色（比如 "#ff0000"）' },
        { value: 'rgb_number', label: '规定颜色值为 rgb 代码的背景颜色（比如 "rgb(255,0,0)"）' }
      ]
    },
    'char': {
      name: '规定根据哪个字符来进行文本对齐，仅当 align 属性设置为 "char" 时，才能使用 char 属性',
      tips: [
        { value: 'character ', label: '规定将内容与之对齐的字符' }
      ]
    },
    'charoff': {
      name: '规定第一个对齐字符的偏移量，设置 char 属性时，才能使用 charoff 属性',
      tips: [
        { value: 'number', label: '规定对齐方式。正数规定向字符的右边对齐。负数规定向字符的左边对齐' }
      ]
    },
    'valign': {
      name: '规定 tfoot 元素中内容的垂直对齐方式',
      tips: [
        { value: 'top', label: '对内容进行上对齐' },
        { value: 'middle', label: '对内容进行居中对齐（默认值）' },
        { value: 'bottom', label: '对内容进行下对齐' },
        { value: 'baseline', label: '与基线对齐' }
      ]
    }
  },
  'track': {
    'default': {
      name: '规定该轨道是默认的，假如没有选择任何轨道',
      tips: [
        { value: 'default', label: '规定该轨道是默认轨道，假如用户未选择其他，则使用这个轨道' }
      ]
    },
    'kind': {
      name: '表示轨道属于什么文本类型',
      tips: [
        { value: 'captions ', label: '该轨道定义将在播放器中显示的简短说明' },
        { value: 'chapters ', label: '该轨道定义章节，用于导航媒介资源' },
        { value: 'descriptions ', label: '该轨道定义描述，用于通过音频描述媒介的内容，假如内容不可播放或不可见' },
        { value: 'metadata ', label: '该轨道定义脚本使用的内容' },
        { value: 'subtitles ', label: '该轨道定义字幕，用于在视频中显示字幕' }
      ]
    },
    'label': {
      name: '轨道的标签或标题',
      tips: [
        { value: 'label ', label: '规定轨道的标签' }
      ]
    },
    'src': {
      name: '轨道的 URL',
      tips: [
        { value: 'url ', label: '规定轨道的 url' }
      ]
    },
    'srclang': {
      name: '轨道的语言，若 kind 属性值是 "subtitles"，则该属性必需的',
      tips: [
        { value: 'zh', label: '中文(简体)' },
        { value: 'en', label: '英文' },
        { value: 'ja', label: '日语' },
        { value: 'ko', label: '韩语' },
        { value: 'https://www.w3school.com.cn/tags/html_ref_language_codes.asp', label: '语言对照表' }
      ]
    }
  },
  'ul': {
    'compact': {
      name: '规定列表呈现的效果比正常情况更小巧(不推荐)',
      tips: [
        { value: 'compact', label: '规定列表呈现更紧凑小巧的效果' }
      ]
    },
    'type': {
      name: '规定列表的项目符号的类型(不推荐)',
      tips: [
        { value: 'disc ', label: '默认值。实心圆' },
        { value: 'circle ', label: '空心圆' },
        { value: 'square ', label: '实心方块' }
      ]
    }
  },
  'video': {
    'autoplay': {
      name: '如果出现该属性，则视频在就绪后马上播放',
      tips: [{ value: 'autoplay', label: '自动播放' }]
    },
    'controls': {
      name: '如果出现该属性，则向用户显示控件，比如播放按钮',
      tips: [{ value: 'controls', label: '控制播放' }]
    },
    'height': {
      name: '设置视频播放器的高度',
      tips: [
        { value: 'pixels', label: '指定视频播放器的高度（比如 "100px"）' },
        { value: '100px', label: '视频播放器的高度100px' }
      ]
    },
    'loop': {
      name: '如果出现该属性，则当媒介文件完成播放后再次开始播放',
      tips: [{ value: 'loop', label: '循环播放' }]
    },
    'muted': {
      name: '规定视频的音频输出应该被静音',
      tips: [{ value: 'muted', label: '静音播放' }]
    },
    'poster': {
      name: '规定视频下载时显示的图像，或者在用户点击播放按钮前显示的图像',
      tips: [{ value: 'URL', label: '规定图像文件的 URL' }]
    },
    'preload': {
      name: '如果出现该属性，则音频在页面加载时进行加载，并预备播放。如果使用 "autoplay"，则忽略该属性',
      tips: [
        { value: 'load', label: '规定是否预加载视频' },
        { value: 'auto', label: '当页面加载后载入整个视频' },
        { value: 'meta', label: '当页面加载后只载入元数据' },
        { value: 'none', label: '当页面加载后不载入视频' }
      ]
    },
    'src': {
      name: '要播放的视频的 URL',
      tips: [{ value: 'url', label: '视频文件的 URL' }]
    },
    'width': {
      name: '设置视频播放器的宽度',
      tips: [
        { value: 'pixels', label: '以像素计的宽度值（比如 "100px"）' },
        { value: '100px', label: '视频播放器的宽度100px' }
      ]
    }
  }

}
